==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WaterfallSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { WaterfallSeriesDescription } from "./WaterfallSeriesDescription";
/**
 * @hidden
 */
var WaterfallSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesDescriptionMetadata, _super);
    function WaterfallSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WaterfallSeriesDescriptionMetadata.b = function (a) {
        if (WaterfallSeriesDescriptionMetadata.a == null) {
            WaterfallSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WaterfallSeriesDescriptionMetadata.c(WaterfallSeriesDescriptionMetadata.a);
        }
        if (a.g(WaterfallSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(WaterfallSeriesDescriptionMetadata.a);
    };
    WaterfallSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("NegativeBrush", "Brush");
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
        a.item("NegativeOutline", "Brush");
    };
    WaterfallSeriesDescriptionMetadata.d = function (a) {
        WaterfallSeriesDescriptionMetadata.b(a);
        a.u("WaterfallSeries", function () { return new WaterfallSeriesDescription(); });
        a.t("WaterfallSeries", WaterfallSeriesDescriptionMetadata.a);
    };
    WaterfallSeriesDescriptionMetadata.$t = markType(WaterfallSeriesDescriptionMetadata, 'WaterfallSeriesDescriptionMetadata');
    WaterfallSeriesDescriptionMetadata.a = null;
    return WaterfallSeriesDescriptionMetadata;
}(Base));
export { WaterfallSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WaterfallSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { WaterfallSeriesDescription } from "./WaterfallSeriesDescription";
/**
 * @hidden
 */
var WaterfallSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesDescriptionMetadata, _super);
    function WaterfallSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WaterfallSeriesDescriptionMetadata.b = function (a) {
        if (WaterfallSeriesDescriptionMetadata.a == null) {
            WaterfallSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WaterfallSeriesDescriptionMetadata.c(WaterfallSeriesDescriptionMetadata.a);
        }
        if (a.j(WaterfallSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(WaterfallSeriesDescriptionMetadata.a);
    };
    WaterfallSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("NegativeBrush", "Brush");
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
        a.item("NegativeOutline", "Brush");
    };
    WaterfallSeriesDescriptionMetadata.d = function (a) {
        WaterfallSeriesDescriptionMetadata.b(a);
        a.aa("WaterfallSeries", function () { return new WaterfallSeriesDescription(); });
        a.z("WaterfallSeries", WaterfallSeriesDescriptionMetadata.a);
    };
    WaterfallSeriesDescriptionMetadata.$t = markType(WaterfallSeriesDescriptionMetadata, 'WaterfallSeriesDescriptionMetadata');
    WaterfallSeriesDescriptionMetadata.a = null;
    return WaterfallSeriesDescriptionMetadata;
}(Base));
export { WaterfallSeriesDescriptionMetadata };
